pystagram.graph_api.components.containers package — pystagram 0.1 documentation

# pystagram.graph_api.components.containers package

## Submodules

## pystagram.graph_api.components.containers.base_container module

class pystagram.graph_api.components.containers.base_container.BaseContainer

  Bases: `ABC`

  Abstract class for an Instagram Container.

  property fields

    Returns the fields of the container as a dictionary.

## pystagram.graph_api.components.containers.carousel_container module

class pystagram.graph_api.components.containers.carousel_container.CarouselContainer(children: List[BaseContainer], caption: str | None = None)

  Bases: `BaseContainer`

  Instagram Carousel Container.

  Parameters:

    - children (List[BaseContainer]) – List of children containers.

    - caption (Optional[str]) – Caption for the carousel.

## pystagram.graph_api.components.containers.image_container module

class pystagram.graph_api.components.containers.image_container.ImageContainer(image_url: str, is_carousel_item: bool | None = False, caption: str | None = None, collaborators: List[str] | None = None, location_id: str | None = None, user_tags: List[UserTag] | None = None, product_tags: List[ProductTag] | None = None)

  Bases: `BaseContainer`

  Instagram Image Container.

  Parameters:

    - image_url (str) – URL of the image, image must be hosted on a publicly accessible server.

    - is_carousel_item (Optional[bool], optional) – Whether th image will appear in a carousel, defaults to False.

    - caption (Optional[str], optional) – Caption for the image.

    - collaborators (Optional[List[str]], optional) – List of collaborators.

    - location_id (Optional[str], optional) – Location ID.

    - user_tags (Optional[List[UserTag]], optional) – List of user tags.

    - product_tags (Optional[List[ProductTag]], optional) – Product tags.

## pystagram.graph_api.components.containers.reel_container module

class pystagram.graph_api.components.containers.reel_container.ReelContainer(video_url: str, share_to_feed: bool | None = True, caption: str | None = None, collaborators: List[str] | None = None, cover_url: str | None = None, audio_name: str | None = None, user_tags: List[UserTag] | None = None, location_id: str | None = None, thumb_offset: int | None = 0)

  Bases: `BaseContainer`

  Instagram Reel Container.

  Parameters:

    - video_url (str) – URL of the video, video must be hosted on a publicly accessible server.

    - share_to_feed (Optional[bool], optional) – Whether to share the reel to the feed, defaults to True.

    - caption (Optional[str], optional) – Caption for the reel.

    - collaborators (Optional[List[str]], optional) – List of collaborators.

    - cover_url (Optional[str], optional) – URL of the cover image, cover image must be hosted on a publicly accessible server.

    - audio_name (Optional[str], optional) – Name of the audio.

    - user_tags (Optional[List[UserTag]], optional) – List of user tags.

    - location_id (Optional[str], optional) – Location ID.

    - thumb_offset (Optional[int], optional) – Thumbnail offset.

## pystagram.graph_api.components.containers.video_container module

class pystagram.graph_api.components.containers.video_container.VideoContainer(video_url: str, is_carousel_item: bool | None = False, caption: str | None = None, collaborators: List[str] | None = None, location_id: str | None = None, user_tags: List[UserTag] | None = None, product_tags: List[ProductTag] | None = None)

  Bases: `BaseContainer`

  Instagram Video Container.

  Parameters:

    - video_url (str) – URL of the video, video must be hosted on a publicly accessible server.

    - is_carousel_item (Optional[bool], optional) – Whether the video will appear in a carousel, defaults to False.

    - caption (Optional[str], optional) – Caption for the video.

    - collaborators (Optional[List[str]], optional) – List of collaborators.

    - location_id (Optional[str], optional) – Location ID.

    - user_tags (Optional[List[UserTag]], optional) – List of user tags.

    - product_tags (Optional[List[ProductTag]], optional) – Product tags.

## Module contents